import contextlib
import os
import shutil
import tempfile
import sys
import traceback

def readtextfile(path):
    return open(path, 'rt', newline='').read()

def readbinaryfile(path):
    return open(path, 'rb').read()

def writebinaryfile(path, body):
    with open(path, 'wb') as g:
        g.write(body)

def make_resp(content, status = 200, mimetype = 'text/plain'):
    import flask
    resp = flask.make_response(content, status)
    resp.headers['Content-Type'] = mimetype
    return resp

@contextlib.contextmanager
def cd(newdir, cleanup=lambda: True):
    prevdir = os.getcwd()
    os.chdir(os.path.expanduser(newdir))
    try:
        yield
    finally:
        os.chdir(prevdir)
        cleanup()

@contextlib.contextmanager
def tempdir(remove_upon_completion=True):
    dirpath = tempfile.mkdtemp()

    def cleanup():
        shutil.rmtree(dirpath)

    if remove_upon_completion:
        with cd(dirpath, cleanup):
            yield dirpath
    else:
        with cd(dirpath):
            yield dirpath

def get_exc_info():
    return '\n'.join(traceback.format_exception(*sys.exc_info()))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pmghelper",
    version="0.0.1",
    author="Preston Meyer Group",
    author_email="dev@pmgroup.ch",
    description="PMG Helper Utilities",
    packages=setuptools.find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License'
    ],
    install_requires=open('requirements.txt', 'r').read(),
    python_requires='~=3.6',
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
)
